@@ -5,7 +5,7 @@ from e3nn import o3
 from e3nn.util.jit import compile_mode
 
 
-@compile_mode('unsupported')
+@compile_mode("unsupported")
 class BatchNorm(nn.Module):
     """Batch normalization for orthonormal representations
 
@@ -33,7 +33,8 @@ class BatchNorm(nn.Module):
     instance : bool
         apply instance norm instead of batch norm
     """
-    def __init__(self, irreps, eps=1e-5, momentum=0.1, affine=True, reduce='mean', instance=False, normalization='component'):
+
+    def __init__(self, irreps, eps=1e-5, momentum=0.1, affine=True, reduce="mean", instance=False, normalization="component"):
         super().__init__()
 
         self.irreps = o3.Irreps(irreps)
@@ -46,24 +47,24 @@ class BatchNorm(nn.Module):
         num_features = self.irreps.num_irreps
 
         if self.instance:
-            self.register_buffer('running_mean', None)
-            self.register_buffer('running_var', None)
+            self.register_buffer("running_mean", None)
+            self.register_buffer("running_var", None)
         else:
-            self.register_buffer('running_mean', torch.zeros(num_scalar))
-            self.register_buffer('running_var', torch.ones(num_features))
+            self.register_buffer("running_mean", torch.zeros(num_scalar))
+            self.register_buffer("running_var", torch.ones(num_features))
 
         if affine:
             self.weight = nn.Parameter(torch.ones(num_features))
             self.bias = nn.Parameter(torch.zeros(num_scalar))
         else:
-            self.register_parameter('weight', None)
-            self.register_parameter('bias', None)
+            self.register_parameter("weight", None)
+            self.register_parameter("bias", None)
 
         assert isinstance(reduce, str), "reduce should be passed as a string value"
-        assert reduce in ['mean', 'max'], "reduce needs to be 'mean' or 'max'"
+        assert reduce in ["mean", "max"], "reduce needs to be 'mean' or 'max'"
         self.reduce = reduce
 
-        assert normalization in ['norm', 'component'], "normalization needs to be 'norm' or 'component'"
+        assert normalization in ["norm", "component"], "normalization needs to be 'norm' or 'component'"
         self.normalization = normalization
 
     def __repr__(self):
@@ -101,7 +102,7 @@ class BatchNorm(nn.Module):
 
         for mul, ir in self.irreps:
             d = ir.dim
-            field = input[:, :, ix: ix + mul * d]  # [batch, sample, mul * repr]
+            field = input[:, :, ix : ix + mul * d]  # [batch, sample, mul * repr]
             ix += mul * d
 
             # [batch, sample, mul, repr]
@@ -113,42 +114,40 @@ class BatchNorm(nn.Module):
                         field_mean = field.mean(1).reshape(batch, mul)  # [batch, mul]
                     else:
                         field_mean = field.mean([0, 1]).reshape(mul)  # [mul]
-                        new_means.append(
-                            self._roll_avg(self.running_mean[irm:irm + mul], field_mean)
-                        )
+                        new_means.append(self._roll_avg(self.running_mean[irm : irm + mul], field_mean))
                 else:
-                    field_mean = self.running_mean[irm: irm + mul]
+                    field_mean = self.running_mean[irm : irm + mul]
                 irm += mul
 
                 # [batch, sample, mul, repr]
                 field = field - field_mean.reshape(-1, 1, mul, 1)
 
             if self.training or self.instance:
-                if self.normalization == 'norm':
+                if self.normalization == "norm":
                     field_norm = field.pow(2).sum(3)  # [batch, sample, mul]
-                elif self.normalization == 'component':
+                elif self.normalization == "component":
                     field_norm = field.pow(2).mean(3)  # [batch, sample, mul]
                 else:
                     raise ValueError("Invalid normalization option {}".format(self.normalization))
 
-                if self.reduce == 'mean':
+                if self.reduce == "mean":
                     field_norm = field_norm.mean(1)  # [batch, mul]
-                elif self.reduce == 'max':
+                elif self.reduce == "max":
                     field_norm = field_norm.max(1).values  # [batch, mul]
                 else:
                     raise ValueError("Invalid reduce option {}".format(self.reduce))
 
                 if not self.instance:
                     field_norm = field_norm.mean(0)  # [mul]
-                    new_vars.append(self._roll_avg(self.running_var[irv: irv + mul], field_norm))
+                    new_vars.append(self._roll_avg(self.running_var[irv : irv + mul], field_norm))
             else:
-                field_norm = self.running_var[irv: irv + mul]
+                field_norm = self.running_var[irv : irv + mul]
             irv += mul
 
             field_norm = (field_norm + self.eps).pow(-0.5)  # [(batch,) mul]
 
             if self.affine:
-                weight = self.weight[iw: iw + mul]  # [mul]
+                weight = self.weight[iw : iw + mul]  # [mul]
                 iw += mul
 
                 field_norm = field_norm * weight  # [(batch,) mul]
@@ -156,7 +155,7 @@ class BatchNorm(nn.Module):
             field = field * field_norm.reshape(-1, 1, mul, 1)  # [batch, sample, mul, repr]
 
             if self.affine and ir.is_scalar():  # scalars
-                bias = self.bias[ib: ib + mul]  # [mul]
+                bias = self.bias[ib : ib + mul]  # [mul]
                 ib += mul
                 field += bias.reshape(mul, 1)  # [batch, sample, mul, repr]
 
@@ -175,8 +174,10 @@ class BatchNorm(nn.Module):
             assert ib == self.bias.numel()
 
         if self.training and not self.instance:
-            torch.cat(new_means, out=self.running_mean)
-            torch.cat(new_vars, out=self.running_var)
+            if len(new_means) > 0:
+                torch.cat(new_means, out=self.running_mean)
+            if len(new_vars) > 0:
+                torch.cat(new_vars, out=self.running_var)
 
         output = torch.cat(fields, dim=2)  # [batch, sample, stacked features]
         return output.reshape(batch, *size, dim)
