@@ -4,7 +4,7 @@ from e3nn import o3
 from e3nn.util.jit import compile_mode
 
 
-@compile_mode('trace')
+@compile_mode("trace")
 class Identity(torch.nn.Module):
     r"""Identity operation
 
@@ -14,6 +14,7 @@ class Identity(torch.nn.Module):
 
     irreps_out : `e3nn.o3.Irreps`
     """
+
     def __init__(self, irreps_in, irreps_out):
         super().__init__()
 
@@ -22,18 +23,16 @@ class Identity(torch.nn.Module):
 
         assert self.irreps_in == self.irreps_out
 
-        output_mask = torch.cat([
-            torch.ones(mul * (2 * l + 1))
-            for mul, (l, _p) in self.irreps_out
-        ])
-        self.register_buffer('output_mask', output_mask)
+        output_mask = torch.cat([torch.ones(mul * (2 * l + 1)) for mul, (l, _p) in self.irreps_out])
+        self.register_buffer("output_mask", output_mask)
 
     def __repr__(self):
         return f"{self.__class__.__name__}({self.irreps_in} -> {self.irreps_out})"
 
     def forward(
-            # pylint: disable=no-self-use
-            self, features):
-        """evaluate
-        """
+        # pylint: disable=no-self-use
+        self,
+        features,
+    ):
+        """evaluate"""
         return features
