@@ -5,12 +5,13 @@ from e3nn.math import normalize2mom
 from e3nn.util.jit import compile_mode
 
 
-@compile_mode('script')
+@compile_mode("script")
 class S2Activation(torch.nn.Module):
-    r'''Apply non linearity on the signal on the sphere
+    r"""Apply non linearity on the signal on the sphere
 
     | Maps to the sphere, apply the non linearity point wise and project back.
-    | The signal on the sphere is a quasiregular representation of :math:`O(3)` and we can apply a pointwise operation on these representations.
+    | The signal on the sphere is a quasiregular representation of :math:`O(3)` and we can apply a pointwise operation on
+    | these representations.
 
     .. math:: \{A^l\}_l \mapsto \{\int \phi(\sum_l A^l \cdot Y^l(x)) Y^j(x) dx\}_j
 
@@ -37,8 +38,9 @@ class S2Activation(torch.nn.Module):
     --------
     >>> from e3nn import io
     >>> m = S2Activation(io.SphericalTensor(5, p_val=+1, p_arg=-1), torch.tanh, 100)
-    '''
-    def __init__(self, irreps: o3.Irreps, act, res, normalization='component', lmax_out=None, random_rot=False):
+    """
+
+    def __init__(self, irreps: o3.Irreps, act, res, normalization="component", lmax_out=None, random_rot=False):
         super().__init__()
 
         irreps = o3.Irreps(irreps).simplify()
@@ -59,16 +61,16 @@ class S2Activation(torch.nn.Module):
             lmax_out = lmax
 
         if p_val in (0, +1):
-            self.irreps_out = o3.Irreps([(1, (l, p_val * p_arg ** l)) for l in range(lmax_out + 1)])
+            self.irreps_out = o3.Irreps([(1, (l, p_val * p_arg**l)) for l in range(lmax_out + 1)])
         if p_val == -1:
             x = torch.linspace(0, 10, 256)
             a1, a2 = act(x), act(-x)
             if (a1 - a2).abs().max() < a1.abs().max() * 1e-10:
                 # p_act = 1
-                self.irreps_out = o3.Irreps([(1, (l, p_arg ** l)) for l in range(lmax_out + 1)])
+                self.irreps_out = o3.Irreps([(1, (l, p_arg**l)) for l in range(lmax_out + 1)])
             elif (a1 + a2).abs().max() < a1.abs().max() * 1e-10:
                 # p_act = -1
-                self.irreps_out = o3.Irreps([(1, (l, -p_arg ** l)) for l in range(lmax_out + 1)])
+                self.irreps_out = o3.Irreps([(1, (l, -(p_arg**l))) for l in range(lmax_out + 1)])
             else:
                 # p_act = 0
                 raise ValueError("warning! the parity is violated")
@@ -82,7 +84,7 @@ class S2Activation(torch.nn.Module):
         return f"{self.__class__.__name__} ({self.irreps_in} -> {self.irreps_out})"
 
     def forward(self, features):
-        r'''evaluate
+        r"""evaluate
 
         Parameters
         ----------
@@ -94,17 +96,17 @@ class S2Activation(torch.nn.Module):
         -------
         `torch.Tensor`
             tensor of shape ``(..., self.irreps_out.dim)``
-        '''
+        """
         assert features.shape[-1] == self.irreps_in.dim
 
         if self.random_rot:
             abc = o3.rand_angles(dtype=features.dtype, device=features.device)
-            features = torch.einsum('ij,...j->...i', self.irreps_in.D_from_angles(*abc), features)
+            features = torch.einsum("ij,...j->...i", self.irreps_in.D_from_angles(*abc), features)
 
         features = self.to_s2(features)  # [..., beta, alpha]
         features = self.act(features)
         features = self.from_s2(features)
 
         if self.random_rot:
-            features = torch.einsum('ij,...j->...i', self.irreps_out.D_from_angles(*abc).T, features)
+            features = torch.einsum("ij,...j->...i", self.irreps_out.D_from_angles(*abc).T, features)
         return features
