@@ -52,6 +52,7 @@ class MessagePassing(torch.nn.Module):
         number of neurons per layers in the fully connected network
         first layer and hidden layers but not the output layer
     """
+
     def __init__(
         self,
         irreps_node_sequence,
@@ -82,39 +83,43 @@ class MessagePassing(torch.nn.Module):
         irreps_node = irreps_node_sequence[0]
 
         for irreps_node_hidden in irreps_node_sequence[1:-1]:
-            irreps_scalars = o3.Irreps([
-                (mul, ir)
-                for mul, ir in irreps_node_hidden
-                if ir.l == 0 and tp_path_exists(irreps_node, self.irreps_edge_attr, ir)
-            ]).simplify()
-            irreps_gated = o3.Irreps([
-                (mul, ir)
-                for mul, ir in irreps_node_hidden
-                if ir.l > 0 and tp_path_exists(irreps_node, self.irreps_edge_attr, ir)
-            ])
+            irreps_scalars = o3.Irreps(
+                [
+                    (mul, ir)
+                    for mul, ir in irreps_node_hidden
+                    if ir.l == 0 and tp_path_exists(irreps_node, self.irreps_edge_attr, ir)
+                ]
+            ).simplify()
+            irreps_gated = o3.Irreps(
+                [
+                    (mul, ir)
+                    for mul, ir in irreps_node_hidden
+                    if ir.l > 0 and tp_path_exists(irreps_node, self.irreps_edge_attr, ir)
+                ]
+            )
             if irreps_gated.dim > 0:
                 if tp_path_exists(irreps_node, self.irreps_edge_attr, "0e"):
                     ir = "0e"
                 elif tp_path_exists(irreps_node, self.irreps_edge_attr, "0o"):
                     ir = "0o"
                 else:
-                    raise ValueError(f"irreps_node={irreps_node} times irreps_edge_attr={self.irreps_edge_attr} is unable to produce gates needed for irreps_gated={irreps_gated}")
+                    raise ValueError(
+                        f"irreps_node={irreps_node} times irreps_edge_attr={self.irreps_edge_attr} is unable to produce gates "
+                        f"needed for irreps_gated={irreps_gated}"
+                    )
             else:
                 ir = None
             irreps_gates = o3.Irreps([(mul, ir) for mul, _ in irreps_gated]).simplify()
 
             gate = Gate(
-                irreps_scalars, [act[ir.p] for _, ir in irreps_scalars],  # scalar
-                irreps_gates, [act_gates[ir.p] for _, ir in irreps_gates],  # gates (scalars)
-                irreps_gated  # gated tensors
+                irreps_scalars,
+                [act[ir.p] for _, ir in irreps_scalars],  # scalar
+                irreps_gates,
+                [act_gates[ir.p] for _, ir in irreps_gates],  # gates (scalars)
+                irreps_gated,  # gated tensors
             )
             conv = Convolution(
-                irreps_node,
-                self.irreps_node_attr,
-                self.irreps_edge_attr,
-                gate.irreps_in,
-                fc_neurons,
-                num_neighbors
+                irreps_node, self.irreps_node_attr, self.irreps_edge_attr, gate.irreps_in, fc_neurons, num_neighbors
             )
             self.layers.append(Compose(conv, gate))
             irreps_node = gate.irreps_out
@@ -123,12 +128,7 @@ class MessagePassing(torch.nn.Module):
         irreps_node_output = irreps_node_sequence[-1]
         self.layers.append(
             Convolution(
-                irreps_node,
-                self.irreps_node_attr,
-                self.irreps_edge_attr,
-                irreps_node_output,
-                fc_neurons,
-                num_neighbors
+                irreps_node, self.irreps_node_attr, self.irreps_edge_attr, irreps_node_output, fc_neurons, num_neighbors
             )
         )
         self.irreps_node_sequence.append(irreps_node_output)
@@ -165,7 +165,9 @@ def test():
     edge_index = radius_graph(node_pos, 3.0)
     edge_src, edge_dst = edge_index
     num_edges = edge_index.shape[1]
-    edge_attr = o3.spherical_harmonics([0, 1], node_pos[edge_src] - node_pos[edge_dst], normalize=True, normalization='component')
+    edge_attr = o3.spherical_harmonics(
+        [0, 1], node_pos[edge_src] - node_pos[edge_dst], normalize=True, normalization="component"
+    )
 
     node_features = torch.randn(num_nodes, 1)
     node_attr = torch.randn(num_nodes, 4)
