@@ -5,6 +5,7 @@ from typing import List, Union
 import torch
 
 from e3nn.math import direct_sum, perm
+
 # These imports avoid cyclic reference from o3 itself
 from . import _rotation
 from . import _wigner
@@ -14,7 +15,8 @@ class Irrep(tuple):
     r"""Irreducible representation of :math:`O(3)`
 
     This class does not contain any data, it is a structure that describe the representation.
-    It is typically used as argument of other classes of the library to define the input and output representations of functions.
+    It is typically used as argument of other classes of the library to define the input and output representations of
+    functions.
 
     Parameters
     ----------
@@ -50,7 +52,8 @@ class Irrep(tuple):
     >>> Irrep("1o") + Irrep("2o")
     1x1o+1x2o
     """
-    def __new__(cls, l: Union[int, 'Irrep', str, tuple], p=None):
+
+    def __new__(cls, l: Union[int, "Irrep", str, tuple], p=None):
         if p is None:
             if isinstance(l, Irrep):
                 return l
@@ -61,21 +64,23 @@ class Irrep(tuple):
                     l = int(name[:-1])
                     assert l >= 0
                     p = {
-                        'e': 1,
-                        'o': -1,
-                        'y': (-1)**l,
+                        "e": 1,
+                        "o": -1,
+                        "y": (-1) ** l,
                     }[name[-1]]
                 except Exception:
-                    raise ValueError(f"unable to convert string \"{name}\" into an Irrep")
+                    raise ValueError(f'unable to convert string "{name}" into an Irrep')
             elif isinstance(l, tuple):
                 l, p = l
 
-        assert isinstance(l, int) and l >= 0, l
-        assert p in [-1, 1], p
+        if not isinstance(l, int) or l < 0:
+            raise ValueError(f"l must be positive integer, got {l}")
+        if p not in (-1, 1):
+            raise ValueError(f"parity must be on of (-1, 1), got {p}")
         return super().__new__(cls, (l, p))
 
     @property
-    def l(self) -> int:
+    def l(self) -> int:  # noqa: E743
         r"""The degree of the representation, :math:`l = 0, 1, \dots`."""
         return self[0]
 
@@ -85,7 +90,7 @@ class Irrep(tuple):
         return self[1]
 
     def __repr__(self):
-        p = {+1: 'e', -1: 'o'}[self.p]
+        p = {+1: "e", -1: "o"}[self.p]
         return f"{self.l}{p}"
 
     @classmethod
@@ -99,8 +104,8 @@ class Irrep(tuple):
         (0e, 0o, 1o, 1e)
         """
         for l in itertools.count():
-            yield Irrep(l, (-1)**l)
-            yield Irrep(l, -(-1)**l)
+            yield Irrep(l, (-1) ** l)
+            yield Irrep(l, -((-1) ** l))
 
             if l == lmax:
                 break
@@ -142,7 +147,7 @@ class Irrep(tuple):
             k = torch.zeros_like(alpha)
 
         alpha, beta, gamma, k = torch.broadcast_tensors(alpha, beta, gamma, k)
-        return _wigner.wigner_D(self.l, alpha, beta, gamma) * self.p**k[..., None, None]
+        return _wigner.wigner_D(self.l, alpha, beta, gamma) * self.p ** k[..., None, None]
 
     def D_from_quaternion(self, q, k=None):
         r"""Matrix of the representation, see `Irrep.D_from_angles`
@@ -191,6 +196,24 @@ class Irrep(tuple):
         k = (1 - d) / 2
         return self.D_from_angles(*_rotation.matrix_to_angles(R), k)
 
+    def D_from_axis_angle(self, axis, angle):
+        r"""Matrix of the representation, see `Irrep.D_from_angles`
+
+        Parameters
+        ----------
+        axis : `torch.Tensor`
+            tensor of shape :math:`(..., 3)`
+
+        angle : `torch.Tensor`
+            tensor of shape :math:`(...)`
+
+        Returns
+        -------
+        `torch.Tensor`
+            tensor of shape :math:`(..., 2l+1, 2l+1)`
+        """
+        return self.D_from_angles(*_rotation.axis_angle_to_angles(axis, angle))
+
     @property
     def dim(self) -> int:
         """The dimension of the representation, :math:`2 l + 1`."""
@@ -262,6 +285,9 @@ class _MulIr(tuple):
     def __repr__(self):
         return f"{self.mul}x{self.ir}"
 
+    def __getitem__(self, item) -> Union[int, Irrep]:  # pylint: disable=useless-super-delegation
+        return super().__getitem__(item)
+
     def count(self, _value):
         raise NotImplementedError
 
@@ -273,7 +299,8 @@ class Irreps(tuple):
     r"""Direct sum of irreducible representations of :math:`O(3)`
 
     This class does not contain any data, it is a structure that describe the representation.
-    It is typically used as argument of other classes of the library to define the input and output representations of functions.
+    It is typically used as argument of other classes of the library to define the input and output representations of
+    functions.
 
     Attributes
     ----------
@@ -319,7 +346,8 @@ class Irreps(tuple):
     >>> Irreps(), Irreps("")
     (, )
     """
-    def __new__(cls, irreps=None) -> Union[_MulIr, 'Irreps']:
+
+    def __new__(cls, irreps=None) -> Union[_MulIr, "Irreps"]:
         if isinstance(irreps, Irreps):
             return super().__new__(cls, irreps)
 
@@ -329,9 +357,9 @@ class Irreps(tuple):
         elif isinstance(irreps, str):
             try:
                 if irreps.strip() != "":
-                    for mul_ir in irreps.split('+'):
-                        if 'x' in mul_ir:
-                            mul, ir = mul_ir.split('x')
+                    for mul_ir in irreps.split("+"):
+                        if "x" in mul_ir:
+                            mul, ir = mul_ir.split("x")
                             mul = int(mul)
                             ir = Irrep(ir)
                         else:
@@ -341,7 +369,7 @@ class Irreps(tuple):
                         assert isinstance(mul, int) and mul >= 0
                         out.append(_MulIr(mul, ir))
             except Exception:
-                raise ValueError(f"Unable to convert string \"{irreps}\" into an Irreps")
+                raise ValueError(f'Unable to convert string "{irreps}" into an Irreps')
         elif irreps is None:
             pass
         else:
@@ -362,7 +390,7 @@ class Irreps(tuple):
                     ir = Irrep(ir)
 
                 if not (isinstance(mul, int) and mul >= 0 and ir is not None):
-                    raise ValueError(f"Unable to interpret \"{mul_ir}\" as an irrep.")
+                    raise ValueError(f'Unable to interpret "{mul_ir}" as an irrep.')
 
                 out.append(_MulIr(mul, ir))
         return super().__new__(cls, out)
@@ -411,7 +439,7 @@ class Irreps(tuple):
             i += mul_ir.dim
         return s
 
-    def randn(self, *size, normalization='component', requires_grad=False, dtype=None, device=None):
+    def randn(self, *size, normalization="component", requires_grad=False, dtype=None, device=None):
         r"""Random tensor.
 
         Parameters
@@ -438,11 +466,11 @@ class Irreps(tuple):
         """
         di = size.index(-1)
         lsize = size[:di]
-        rsize = size[di + 1:]
+        rsize = size[di + 1 :]
 
-        if normalization == 'component':
+        if normalization == "component":
             return torch.randn(*lsize, self.dim, *rsize, requires_grad=requires_grad, dtype=dtype, device=device)
-        elif normalization == 'norm':
+        elif normalization == "norm":
             x = torch.zeros(*lsize, self.dim, *rsize, requires_grad=requires_grad, dtype=dtype, device=device)
             with torch.no_grad():
                 for s, (mul, ir) in zip(self.slices(), self):
@@ -453,7 +481,7 @@ class Irreps(tuple):
         else:
             raise ValueError("Normalization needs to be 'norm' or 'component'")
 
-    def __getitem__(self, i) -> Union[_MulIr, 'Irreps']:
+    def __getitem__(self, i) -> Union[_MulIr, "Irreps"]:
         x = super().__getitem__(i)
         if isinstance(i, slice):
             return Irreps(x)
@@ -501,7 +529,7 @@ class Irreps(tuple):
         """
         return Irreps(super().__rmul__(other))
 
-    def simplify(self):
+    def simplify(self) -> 'Irreps':
         """Simplify the representations.
 
         Returns
@@ -655,3 +683,21 @@ class Irreps(tuple):
         R = d[..., None, None] * R
         k = (1 - d) / 2
         return self.D_from_angles(*_rotation.matrix_to_angles(R), k)
+
+    def D_from_axis_angle(self, axis, angle):
+        r"""Matrix of the representation
+
+        Parameters
+        ----------
+        axis : `torch.Tensor`
+            tensor of shape :math:`(..., 3)`
+
+        angle : `torch.Tensor`
+            tensor of shape :math:`(...)`
+
+        Returns
+        -------
+        `torch.Tensor`
+            tensor of shape :math:`(..., \mathrm{dim}, \mathrm{dim})`
+        """
+        return self.D_from_angles(*_rotation.axis_angle_to_angles(axis, angle))
