@@ -4,7 +4,7 @@ from e3nn import o3
 from e3nn.util.jit import compile_mode
 
 
-@compile_mode('trace')
+@compile_mode("trace")
 class Norm(torch.nn.Module):
     r"""Norm of each irrep in a direct sum of irreps.
 
@@ -26,28 +26,15 @@ class Norm(torch.nn.Module):
     """
     squared: bool
 
-    def __init__(
-        self,
-        irreps_in,
-        squared: bool = False
-    ):
+    def __init__(self, irreps_in, squared: bool = False):
         super().__init__()
 
         irreps_in = o3.Irreps(irreps_in).simplify()
         irreps_out = o3.Irreps([(mul, "0e") for mul, _ in irreps_in])
 
-        instr = [
-            (i, i, i, 'uuu', False, ir.dim)
-            for i, (mul, ir) in enumerate(irreps_in)
-        ]
+        instr = [(i, i, i, "uuu", False, ir.dim) for i, (mul, ir) in enumerate(irreps_in)]
 
-        self.tp = o3.TensorProduct(
-            irreps_in,
-            irreps_in,
-            irreps_out,
-            instr,
-            irrep_normalization='component'
-        )
+        self.tp = o3.TensorProduct(irreps_in, irreps_in, irreps_out, instr, irrep_normalization="component")
 
         self.irreps_in = irreps_in
         self.irreps_out = irreps_out.simplify()
