@@ -1,20 +1,27 @@
-import warnings
 from math import sqrt
-from typing import List, Optional, Union, Any
+from typing import List, Optional, Union, Any, Callable
+import warnings
+
+import torch
+from torch import fx
 
 import e3nn
-import torch
-import torch.fx
 from e3nn import o3
 from e3nn.util import prod
 from e3nn.util.codegen import CodeGenMixin
 from e3nn.util.jit import compile_mode
-from torch import fx
 from ._codegen import codegen_tensor_product_left_right, codegen_tensor_product_right
 from ._instruction import Instruction
 
 
-@compile_mode('script')
+# A list, in order of priority, of codegen providers for the tensor product.
+# If a provider does not support the parameters it is given, it should
+# return `None`, in which case the next provider in the list will be tried.
+_CODEGEN_PROVIDERS_LEFT_RIGHT: List[Callable] = [codegen_tensor_product_left_right]
+_CODEGEN_PROVIDERS_RIGHT: List[Callable] = [codegen_tensor_product_right]
+
+
+@compile_mode("script")
 class TensorProduct(CodeGenMixin, torch.nn.Module):
     r"""Tensor product with parametrized paths.
 
@@ -34,9 +41,11 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
 
         Each instruction puts ``in1[i_1]`` :math:`\otimes` ``in2[i_2]`` into ``out[i_out]``.
 
-        * ``mode``: `str`. Determines the way the multiplicities are treated, ``"uvw"`` is fully connected. Other valid options are: ``'uvw'``, ``'uvu'``, ``'uvv'``, ``'uuw'``, ``'uuu'``, and ``'uvuv'``.
+        * ``mode``: `str`. Determines the way the multiplicities are treated, ``"uvw"`` is fully connected. Other valid
+        options are: ``'uvw'``, ``'uvu'``, ``'uvv'``, ``'uuw'``, ``'uuu'``, and ``'uvuv'``.
         * ``train``: `bool`. `True` if this path should have learnable weights, otherwise `False`.
-        * ``path_weight``: `float`. A fixed multiplicative weight to apply to the output of this path. Defaults to 1. Note that setting ``path_weight`` breaks the normalization derived from ``in1_var``/``in2_var``/``out_var``.
+        * ``path_weight``: `float`. A fixed multiplicative weight to apply to the output of this path. Defaults to 1. Note
+        that setting ``path_weight`` breaks the normalization derived from ``in1_var``/``in2_var``/``out_var``.
 
     in1_var : list of float, Tensor, or None
         Variance for each irrep in ``irreps_in1``. If ``None``, all default to ``1.0``.
@@ -56,7 +65,8 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
 
     path_normalization : {'element', 'path'}
         If set to ``element``, each output is normalized by the total number of elements (independently of their paths).
-        If it is set to ``path``, each path is normalized by the total number of elements in the path, then each output is normalized by the number of paths.
+        If it is set to ``path``, each path is normalized by the total number of elements in the path, then each output is
+        normalized by the number of paths.
 
     internal_weights : bool
         whether the `e3nn.o3.TensorProduct` contains its learnable weights as a parameter
@@ -198,26 +208,23 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         compile_right: bool = False,
         normalization=None,  # for backward compatibility
         _specialized_code: Optional[bool] = None,
-        _optimize_einsums: Optional[bool] = None
+        _optimize_einsums: Optional[bool] = None,
     ):
         # === Setup ===
         super().__init__()
 
         if normalization is not None:
-            warnings.warn(
-                "`normalization` is deprecated. Use `irrep_normalization` instead.",
-                DeprecationWarning
-            )
+            warnings.warn("`normalization` is deprecated. Use `irrep_normalization` instead.", DeprecationWarning)
             irrep_normalization = normalization
 
         if irrep_normalization is None:
-            irrep_normalization = 'component'
+            irrep_normalization = "component"
 
         if path_normalization is None:
-            path_normalization = 'element'
+            path_normalization = "element"
 
-        assert irrep_normalization in ['component', 'norm', 'none']
-        assert path_normalization in ['element', 'path', 'none']
+        assert irrep_normalization in ["component", "norm", "none"]
+        assert path_normalization in ["element", "path", "none"]
 
         self.irreps_in1 = o3.Irreps(irreps_in1)
         self.irreps_in2 = o3.Irreps(irreps_in2)
@@ -234,14 +241,14 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
                 has_weight=has_weight,
                 path_weight=path_weight,
                 path_shape={
-                    'uvw': (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul, self.irreps_out[i_out].mul),
-                    'uvu': (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
-                    'uvv': (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
-                    'uuw': (self.irreps_in1[i_in1].mul, self.irreps_out[i_out].mul),
-                    'uuu': (self.irreps_in1[i_in1].mul,),
-                    'uvuv': (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
-                    'uvu<v': (self.irreps_in1[i_in1].mul * (self.irreps_in2[i_in2].mul - 1) // 2,),
-                    'u<vw': (self.irreps_in1[i_in1].mul * (self.irreps_in2[i_in2].mul - 1) // 2, self.irreps_out[i_out].mul),
+                    "uvw": (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul, self.irreps_out[i_out].mul),
+                    "uvu": (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
+                    "uvv": (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
+                    "uuw": (self.irreps_in1[i_in1].mul, self.irreps_out[i_out].mul),
+                    "uuu": (self.irreps_in1[i_in1].mul,),
+                    "uvuv": (self.irreps_in1[i_in1].mul, self.irreps_in2[i_in2].mul),
+                    "uvu<v": (self.irreps_in1[i_in1].mul * (self.irreps_in2[i_in2].mul - 1) // 2,),
+                    "u<vw": (self.irreps_in1[i_in1].mul * (self.irreps_in2[i_in2].mul - 1) // 2, self.irreps_out[i_out].mul),
                 }[connection_mode],
             )
             for i_in1, i_in2, i_out, connection_mode, has_weight, path_weight in instructions
@@ -267,14 +274,14 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
 
         def num_elements(ins):
             return {
-                'uvw': (self.irreps_in1[ins.i_in1].mul * self.irreps_in2[ins.i_in2].mul),
-                'uvu': self.irreps_in2[ins.i_in2].mul,
-                'uvv': self.irreps_in1[ins.i_in1].mul,
-                'uuw': self.irreps_in1[ins.i_in1].mul,
-                'uuu': 1,
-                'uvuv': 1,
-                'uvu<v': 1,
-                'u<vw': self.irreps_in1[ins.i_in1].mul * (self.irreps_in2[ins.i_in2].mul - 1) // 2,
+                "uvw": (self.irreps_in1[ins.i_in1].mul * self.irreps_in2[ins.i_in2].mul),
+                "uvu": self.irreps_in2[ins.i_in2].mul,
+                "uvv": self.irreps_in1[ins.i_in1].mul,
+                "uuw": self.irreps_in1[ins.i_in1].mul,
+                "uuu": 1,
+                "uvuv": 1,
+                "uvu<v": 1,
+                "u<vw": self.irreps_in1[ins.i_in1].mul * (self.irreps_in2[ins.i_in2].mul - 1) // 2,
             }[ins.connection_mode]
 
         normalization_coefficients = []
@@ -284,25 +291,21 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
             mul_ir_out = self.irreps_out[ins.i_out]
             assert mul_ir_in1.ir.p * mul_ir_in2.ir.p == mul_ir_out.ir.p
             assert abs(mul_ir_in1.ir.l - mul_ir_in2.ir.l) <= mul_ir_out.ir.l <= mul_ir_in1.ir.l + mul_ir_in2.ir.l
-            assert ins.connection_mode in ['uvw', 'uvu', 'uvv', 'uuw', 'uuu', 'uvuv', 'uvu<v', 'u<vw']
+            assert ins.connection_mode in ["uvw", "uvu", "uvv", "uuw", "uuu", "uvuv", "uvu<v", "u<vw"]
 
-            if irrep_normalization == 'component':
+            if irrep_normalization == "component":
                 alpha = mul_ir_out.ir.dim
-            if irrep_normalization == 'norm':
+            if irrep_normalization == "norm":
                 alpha = mul_ir_in1.ir.dim * mul_ir_in2.ir.dim
-            if irrep_normalization == 'none':
+            if irrep_normalization == "none":
                 alpha = 1
 
-            if path_normalization == 'element':
-                x = sum(
-                    in1_var[i.i_in1] * in2_var[i.i_in2] * num_elements(i)
-                    for i in instructions
-                    if i.i_out == ins.i_out
-                )
-            if path_normalization == 'path':
+            if path_normalization == "element":
+                x = sum(in1_var[i.i_in1] * in2_var[i.i_in2] * num_elements(i) for i in instructions if i.i_out == ins.i_out)
+            if path_normalization == "path":
                 x = in1_var[ins.i_in1] * in2_var[ins.i_in2] * num_elements(ins)
                 x *= len([i for i in instructions if i.i_out == ins.i_out])
-            if path_normalization == 'none':
+            if path_normalization == "none":
                 x = 1
 
             if x > 0.0:
@@ -335,56 +338,64 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         self.shared_weights = shared_weights
 
         opt_defaults = e3nn.get_optimization_defaults()
-        self._specialized_code = _specialized_code if _specialized_code is not None else opt_defaults['specialized_code']
-        self._optimize_einsums = _optimize_einsums if _optimize_einsums is not None else opt_defaults['optimize_einsums']
+        self._specialized_code = _specialized_code if _specialized_code is not None else opt_defaults["specialized_code"]
+        self._optimize_einsums = _optimize_einsums if _optimize_einsums is not None else opt_defaults["optimize_einsums"]
         del opt_defaults
 
         # Generate the actual tensor product code
         if compile_left_right:
-            graphmod_left_right = codegen_tensor_product_left_right(
-                self.irreps_in1,
-                self.irreps_in2,
-                self.irreps_out,
-                self.instructions,
-                self.shared_weights,
-                self._specialized_code,
-                self._optimize_einsums
-            )
+            for codegen in _CODEGEN_PROVIDERS_LEFT_RIGHT:
+                graphmod_left_right = codegen(
+                    self.irreps_in1,
+                    self.irreps_in2,
+                    self.irreps_out,
+                    self.instructions,
+                    self.shared_weights,
+                    self._specialized_code,
+                    self._optimize_einsums,
+                )
+                if graphmod_left_right is not None:
+                    break
+            assert graphmod_left_right is not None
         else:
             graphmod_left_right = fx.Graph()
-            graphmod_left_right.placeholder('x1', torch.Tensor)
-            graphmod_left_right.placeholder('x2', torch.Tensor)
-            graphmod_left_right.placeholder('w', torch.Tensor)
+            graphmod_left_right.placeholder("x1", torch.Tensor)
+            graphmod_left_right.placeholder("x2", torch.Tensor)
+            graphmod_left_right.placeholder("w", torch.Tensor)
             graphmod_left_right.call_function(
                 torch._assert,
-                args=(False, "`left_right` method is not compiled, set `compile_left_right` to True when creating the TensorProduct")
+                args=(
+                    False,
+                    "`left_right` method is not compiled, set `compile_left_right` to True when creating the TensorProduct",
+                ),
             )
             graphmod_left_right = fx.GraphModule(torch.nn.Module(), graphmod_left_right, class_name="tp_forward")
 
         if compile_right:
-            graphmod_right = codegen_tensor_product_right(
-                self.irreps_in1,
-                self.irreps_in2,
-                self.irreps_out,
-                self.instructions,
-                self.shared_weights,
-                self._specialized_code,
-                self._optimize_einsums
-            )
+            for codegen in _CODEGEN_PROVIDERS_RIGHT:
+                graphmod_right = codegen(
+                    self.irreps_in1,
+                    self.irreps_in2,
+                    self.irreps_out,
+                    self.instructions,
+                    self.shared_weights,
+                    self._specialized_code,
+                    self._optimize_einsums,
+                )
+                if graphmod_right is not None:
+                    break
+            assert graphmod_right is not None
         else:
             graphmod_right = fx.Graph()
-            graphmod_right.placeholder('x2', torch.Tensor)
-            graphmod_right.placeholder('w', torch.Tensor)
+            graphmod_right.placeholder("x2", torch.Tensor)
+            graphmod_right.placeholder("w", torch.Tensor)
             graphmod_right.call_function(
                 torch._assert,
-                args=(False, "`right` method is not compiled, set `compile_right` to True when creating the TensorProduct")
+                args=(False, "`right` method is not compiled, set `compile_right` to True when creating the TensorProduct"),
             )
             graphmod_right = fx.GraphModule(torch.nn.Module(), graphmod_right, class_name="tp_forward")
 
-        self._codegen_register({
-            "_compiled_main_left_right": graphmod_left_right,
-            "_compiled_main_right": graphmod_right
-        })
+        self._codegen_register({"_compiled_main_left_right": graphmod_left_right, "_compiled_main_right": graphmod_right})
 
         # === Determine weights ===
         self.weight_numel = sum(prod(ins.path_shape) for ins in self.instructions if ins.has_weight)
@@ -394,21 +405,23 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
             self.weight = torch.nn.Parameter(torch.randn(self.weight_numel))
         else:
             # For TorchScript, there always has to be some kind of defined .weight
-            self.register_buffer('weight', torch.Tensor())
+            self.register_buffer("weight", torch.Tensor())
 
         if self.irreps_out.dim > 0:
-            output_mask = torch.cat([
-                torch.ones(mul * ir.dim)
-                if any(
-                    (ins.i_out == i_out) and (ins.path_weight != 0) and (0 not in ins.path_shape)
-                    for ins in self.instructions
-                )
-                else torch.zeros(mul * ir.dim)
-                for i_out, (mul, ir) in enumerate(self.irreps_out)
-            ])
+            output_mask = torch.cat(
+                [
+                    torch.ones(mul * ir.dim)
+                    if any(
+                        (ins.i_out == i_out) and (ins.path_weight != 0) and (0 not in ins.path_shape)
+                        for ins in self.instructions
+                    )
+                    else torch.zeros(mul * ir.dim)
+                    for i_out, (mul, ir) in enumerate(self.irreps_out)
+                ]
+            )
         else:
             output_mask = torch.ones(0)
-        self.register_buffer('output_mask', output_mask)
+        self.register_buffer("output_mask", output_mask)
 
         # For TorchScript, this needs to be done in advance:
         self._profiling_str = str(self)
@@ -528,17 +541,14 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         real_weight = self._get_weights(weight)
         return self._compiled_main_left_right(x, y, real_weight)
 
-    def weight_view_for_instruction(
-        self,
-        instruction: int,
-        weight: Optional[torch.Tensor] = None
-    ) -> torch.Tensor:
+    def weight_view_for_instruction(self, instruction: int, weight: Optional[torch.Tensor] = None) -> torch.Tensor:
         r"""View of weights corresponding to ``instruction``.
 
         Parameters
         ----------
         instruction : int
-            The index of the instruction to get a view on the weights for. ``self.instructions[instruction].has_weight`` must be ``True``.
+            The index of the instruction to get a view on the weights for. ``self.instructions[instruction].has_weight`` must
+            be ``True``.
 
         weight : `torch.Tensor`, optional
             like ``weight`` argument to ``forward()``
@@ -546,7 +556,8 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         Returns
         -------
         `torch.Tensor`
-            A view on ``weight`` or this object's internal weights for the weights corresponding to the ``instruction`` th instruction.
+            A view on ``weight`` or this object's internal weights for the weights corresponding to the ``instruction`` th
+            instruction.
         """
         if not self.instructions[instruction].has_weight:
             raise ValueError(f"Instruction {instruction} has no weights.")
@@ -556,11 +567,7 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         batchshape = weight.shape[:-1]
         return weight.narrow(-1, offset, prod(ins.path_shape)).view(batchshape + ins.path_shape)
 
-    def weight_views(
-        self,
-        weight: Optional[torch.Tensor] = None,
-        yield_instruction: bool = False
-    ):
+    def weight_views(self, weight: Optional[torch.Tensor] = None, yield_instruction: bool = False):
         r"""Iterator over weight views for each weighted instruction.
 
         Parameters
@@ -590,11 +597,7 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
                     yield this_weight
 
     def visualize(
-        self,
-        weight: Optional[torch.Tensor] = None,
-        plot_weight: bool = True,
-        aspect_ratio=1,
-        ax=None
+        self, weight: Optional[torch.Tensor] = None, plot_weight: bool = True, aspect_ratio=1, ax=None
     ):  # pragma: no cover
         r"""Visualize the connectivity of this `e3nn.o3.TensorProduct`
 
@@ -635,16 +638,14 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         fig = ax.get_figure()
 
         # hexagon
-        verts = [
-            np.array([np.cos(a * 2 * np.pi / 6), np.sin(a * 2 * np.pi / 6)])
-            for a in range(6)
-        ]
+        verts = [np.array([np.cos(a * 2 * np.pi / 6), np.sin(a * 2 * np.pi / 6)]) for a in range(6)]
         verts = np.asarray(verts)
 
         # scale it
-        assert aspect_ratio in ['auto'] or isinstance(aspect_ratio, (float, int))
+        if not (aspect_ratio in ["auto"] or isinstance(aspect_ratio, (float, int))):
+            raise ValueError(f"aspect_ratio must be 'auto' or a float or int, got {aspect_ratio}")
 
-        if aspect_ratio == 'auto':
+        if aspect_ratio == "auto":
             factor = 0.2 / 2
             min_aspect = 1 / 2
             h_factor = max(len(self.irreps_in2), len(self.irreps_in1))
@@ -662,16 +663,14 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         codes = [
             Path.MOVETO,
             Path.LINETO,
-
             Path.MOVETO,
             Path.LINETO,
-
             Path.MOVETO,
             Path.LINETO,
         ]
 
         path = Path(verts, codes)
-        patch = patches.PathPatch(path, facecolor='none', lw=1, zorder=2)
+        patch = patches.PathPatch(path, facecolor="none", lw=1, zorder=2)
         ax.add_patch(patch)
 
         n = len(self.irreps_in1)
@@ -699,13 +698,13 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
                 path_weight = []
                 for ins_i, ins in enumerate(self.instructions):
                     if ins.has_weight:
-                        this_weight = self.weight_view_for_instruction(ins_i, weight=weight)
+                        this_weight = self.weight_view_for_instruction(ins_i, weight=weight).cpu()
                         path_weight.append(this_weight.pow(2).mean())
                     else:
                         path_weight.append(0)
                 path_weight = np.asarray(path_weight)
                 path_weight /= np.abs(path_weight).max()
-        cmap = matplotlib.cm.get_cmap('Blues')
+        cmap = matplotlib.cm.get_cmap("Blues")
 
         for ins_index, ins in enumerate(self.instructions):
             y = _intersection(s_in1[ins.i_in1], c_in1, s_in2[ins.i_in2], c_in2)
@@ -720,18 +719,20 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
             codes += [Path.MOVETO, Path.LINETO]
 
             if plot_weight:
-                color = cmap(0.5 + 0.5 * path_weight[ins_index]) if ins.has_weight else 'black'
+                color = cmap(0.5 + 0.5 * path_weight[ins_index]) if ins.has_weight else "black"
             else:
-                color = 'green' if ins.has_weight else 'black'
+                color = "green" if ins.has_weight else "black"
 
-            ax.add_patch(patches.PathPatch(
-                Path(verts, codes),
-                facecolor='none',
-                edgecolor=color,
-                alpha=0.5,
-                ls='-',
-                lw=1.5,
-            ))
+            ax.add_patch(
+                patches.PathPatch(
+                    Path(verts, codes),
+                    facecolor="none",
+                    edgecolor=color,
+                    alpha=0.5,
+                    ls="-",
+                    lw=1.5,
+                )
+            )
 
         # add labels
         padding = 3
@@ -746,37 +747,37 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
             ax.annotate(
                 format_ir(mul_ir),
                 s_in1[i],
-                horizontalalignment='right',
-                textcoords='offset points',
+                horizontalalignment="right",
+                textcoords="offset points",
                 xytext=(-padding, 0),
-                fontsize=fontsize
+                fontsize=fontsize,
             )
 
         for i, mul_ir in enumerate(self.irreps_in2):
             ax.annotate(
                 format_ir(mul_ir),
                 s_in2[i],
-                horizontalalignment='left',
-                textcoords='offset points',
+                horizontalalignment="left",
+                textcoords="offset points",
                 xytext=(padding, 0),
-                fontsize=fontsize
+                fontsize=fontsize,
             )
 
         for i, mul_ir in enumerate(self.irreps_out):
             ax.annotate(
                 format_ir(mul_ir),
                 s_out[i],
-                horizontalalignment='center',
-                verticalalignment='top',
+                horizontalalignment="center",
+                verticalalignment="top",
                 rotation=90,
-                textcoords='offset points',
+                textcoords="offset points",
                 xytext=(0, -padding),
-                fontsize=fontsize
+                fontsize=fontsize,
             )
 
         ax.set_xlim(-2, 2)
         ax.set_ylim(-2, 2)
-        ax.axis('equal')
-        ax.axis('off')
+        ax.axis("equal")
+        ax.axis("off")
 
         return fig, ax
