@@ -28,13 +28,7 @@ def _logging_name(func) -> str:
 
 
 # The default float tolerance
-FLOAT_TOLERANCE = {
-    t: torch.as_tensor(v, dtype=t)
-    for t, v in {
-        torch.float32: 1e-3,
-        torch.float64: 1e-10
-    }.items()
-}
+FLOAT_TOLERANCE = {t: torch.as_tensor(v, dtype=t) for t, v in {torch.float32: 1e-3, torch.float64: 1e-9}.items()}
 
 
 try:
@@ -42,24 +36,23 @@ try:
     # See https://docs.pytest.org/en/stable/fixture.html#using-fixtures-from-other-projects
     import pytest
 
-    @pytest.fixture(scope='session', autouse=True, params=['float32', 'float64'])
+    @pytest.fixture(scope="session", autouse=True, params=["float32", "float64"])
     def float_tolerance(request):
         """Run all tests with various PyTorch default dtypes.
 
-        This is a session-wide, autouse fixture — you only need to request it explicitly if a test needs to know the tolerance for the current default dtype.
+        This is a session-wide, autouse fixture — you only need to request it explicitly if a test needs to know the tolerance
+        for the current default dtype.
 
         Returns
         --------
             A precision threshold to use for closeness tests.
         """
         old_dtype = torch.get_default_dtype()
-        dtype = {
-            'float32': torch.float32,
-            'float64': torch.float64
-        }[request.param]
+        dtype = {"float32": torch.float32, "float64": torch.float64}[request.param]
         torch.set_default_dtype(dtype)
         yield FLOAT_TOLERANCE[dtype]
         torch.set_default_dtype(old_dtype)
+
 except ImportError:
     pass
 
@@ -72,7 +65,7 @@ def random_irreps(
     len_min: int = 0,
     len_max: int = 4,
     clean: bool = False,
-    allow_empty: bool = True
+    allow_empty: bool = True,
 ):
     r"""Generate random irreps parameters for testing.
 
@@ -91,7 +84,8 @@ def random_irreps(
         len_max : int, optional
             The largest number of irreps to generate, defaults to 4.
         clean : bool, optional
-            If ``True``, only ``o3.Irreps`` objects will be returned. If ``False`` (the default), ``e3nn.o3.Irreps``-like objects like strings and lists of tuples can be returned.
+            If ``True``, only ``o3.Irreps`` objects will be returned. If ``False`` (the default), ``e3nn.o3.Irreps``-like
+            objects like strings and lists of tuples can be returned.
         allow_empty : bool, optional
             Whether to allow generating empty ``e3nn.o3.Irreps``.
     Returns
@@ -112,10 +106,7 @@ def random_irreps(
     for _ in range(n):
         this_irreps = []
         for _ in range(random.randint(len_min, len_max)):
-            this_irreps.append((
-                random.randint(mul_min, mul_max),
-                (random.randint(0, lmax), random.choice((1, -1)))
-            ))
+            this_irreps.append((random.randint(mul_min, mul_max), (random.randint(0, lmax), random.choice((1, -1)))))
         if not allow_empty and all(m == 0 for m, _ in this_irreps):
             this_irreps[-1] = (random.randint(1, mul_max), this_irreps[-1][1])
         this_irreps = o3.Irreps(this_irreps)
@@ -151,35 +142,27 @@ def format_equivariance_error(errors: dict) -> str:
     """
     return "\n".join(
         "(parity_k={:d}, did_translate={}) -> max error={:.3e} in argument {}".format(
-            int(k[0]),
-            bool(k[1]),
-            float(v.max()),
-            int(v.argmax())
+            int(k[0]), bool(k[1]), float(v.max()), int(v.argmax())
         )
         for k, v in errors.items()
     )
 
 
-def assert_equivariant(
-    func,
-    args_in=None,
-    irreps_in=None,
-    irreps_out=None,
-    tolerance=None,
-    **kwargs
-) -> dict:
+def assert_equivariant(func, args_in=None, irreps_in=None, irreps_out=None, tolerance=None, **kwargs) -> dict:
     r"""Assert that ``func`` is equivariant.
 
     Parameters
     ----------
         args_in : list or None
-            the original input arguments for the function. If ``None`` and the function has ``irreps_in`` consisting only of ``o3.Irreps`` and ``'cartesian'``, random test inputs will be generated.
+            the original input arguments for the function. If ``None`` and the function has ``irreps_in`` consisting only of
+            ``o3.Irreps`` and ``'cartesian'``, random test inputs will be generated.
         irreps_in : object
             see ``equivariance_error``
         irreps_out : object
             see ``equivariance_error``
         tolerance : float or None
-            the threshold below which the equivariance error must fall. If ``None``, (the default), ``FLOAT_TOLERANCE[torch.get_default_dtype()]`` is used.
+            the threshold below which the equivariance error must fall.
+            If ``None``, (the default), ``FLOAT_TOLERANCE[torch.get_default_dtype()]`` is used.
         **kwargs : kwargs
             passed through to ``equivariance_error``.
 
@@ -190,21 +173,10 @@ def assert_equivariant(
     # Prevent pytest from showing this function in the traceback
     __tracebackhide__ = True
 
-    args_in, irreps_in, irreps_out = _get_args_in(
-        func,
-        args_in=args_in,
-        irreps_in=irreps_in,
-        irreps_out=irreps_out
-    )
+    args_in, irreps_in, irreps_out = _get_args_in(func, args_in=args_in, irreps_in=irreps_in, irreps_out=irreps_out)
 
     # Get error
-    errors = equivariance_error(
-        func,
-        args_in=args_in,
-        irreps_in=irreps_in,
-        irreps_out=irreps_out,
-        **kwargs
-    )
+    errors = equivariance_error(func, args_in=args_in, irreps_in=irreps_in, irreps_out=irreps_out, **kwargs)
 
     logger.info(
         "Tested equivariance of `%s` -- max componentwise errors:\n%s",
@@ -234,7 +206,7 @@ def equivariance_error(
     ntrials=1,
     do_parity=True,
     do_translation=True,
-    transform_dtype=torch.float64
+    transform_dtype=torch.float64,
 ):
     r"""Get the maximum equivariance error for ``func`` over ``ntrials``
 
@@ -247,7 +219,10 @@ def equivariance_error(
     args_in : list
         the original inputs to pass to ``func``.
     irreps_in : list of `e3nn.o3.Irreps` or `e3nn.o3.Irreps`
-        the input irreps for each of the arguments in ``args_in``. If left as the default of ``None``, ``get_io_irreps`` will be used to try to infer them. If a sequence is provided, valid elements are also the string ``'cartesian'``, which denotes that the corresponding input should be dealt with as cartesian points in 3D, and ``None``, which indicates that the argument should not be transformed.
+        the input irreps for each of the arguments in ``args_in``. If left as the default of ``None``, ``get_io_irreps`` will
+        be used to try to infer them. If a sequence is provided, valid elements are also the string ``'cartesian'``, which
+        denotes that the corresponding input should be dealt with as cartesian points in 3D, and ``None``, which indicates
+        that the argument should not be transformed.
     irreps_out : list of `e3nn.o3.Irreps` or `e3nn.o3.Irreps`
         the out irreps for each of the return values of ``func``. Accepts similar values to ``irreps_in``.
     ntrials : int
@@ -269,7 +244,7 @@ def equivariance_error(
     else:
         parity_ks = [0]
 
-    if 'cartesian_points' not in irreps_in:
+    if "cartesian_points" not in irreps_in:
         # There's nothing to translate
         do_translation = False
     if do_translation:
@@ -281,10 +256,7 @@ def equivariance_error(
 
     neg_inf = -float("Inf")
     device = next(t.device for t in args_in if isinstance(t, torch.Tensor))
-    biggest_errs = {
-        test: torch.full((len(irreps_out),), neg_inf, dtype=transform_dtype, device=device)
-        for test in tests
-    }
+    biggest_errs = {test: torch.full((len(irreps_out),), neg_inf, dtype=transform_dtype, device=device) for test in tests}
 
     for trial in range(ntrials):
         for this_test in tests:
@@ -292,9 +264,9 @@ def equivariance_error(
             # Build a rotation matrix for point data
             rot_mat = o3.rand_matrix(dtype=transform_dtype)
             # add parity
-            rot_mat *= (-1)**parity_k
+            rot_mat *= (-1) ** parity_k
             # build translation
-            translation = 10 * torch.randn(1, 3, dtype=rot_mat.dtype) if this_do_translate else 0.
+            translation = 10 * torch.randn(1, 3, dtype=rot_mat.dtype) if this_do_translate else 0.0
 
             # Evaluate the function on rotated arguments:
             rot_args = _transform(args_in, irreps_in, rot_mat, translation)
@@ -329,17 +301,12 @@ def equivariance_error(
 
             # compute errors in the transform dtype,
             # then convert back to default later
-            errors = torch.stack([
-                (a - b).abs().max()
-                for a, b in zip(x1, x2)
-            ])
+            errors = torch.stack([(a - b).abs().max() for a, b in zip(x1, x2)])
 
             biggest_errs[this_test] = torch.where(errors > biggest_errs[this_test], errors, biggest_errs[this_test])
 
     # convert errors back to default dtype to return:
-    return {
-        k: v.to(torch.get_default_dtype()) for k, v in biggest_errs.items()
-    }
+    return {k: v.to(torch.get_default_dtype()) for k, v in biggest_errs.items()}
 
 
 # TODO: this is only for things marked with @compile_mode.
@@ -359,7 +326,8 @@ def assert_auto_jitable(
         error_on_warnings : bool
             If True (default), TracerWarnings emitted by ``torch.jit.trace`` will be treated as errors.
         n_random_tests : int
-            If ``args_in`` is ``None`` and arguments are being automatically generated, this many random arguments will be generated as test inputs for ``torch.jit.trace``.
+            If ``args_in`` is ``None`` and arguments are being automatically generated, this many random arguments will be
+            generated as test inputs for ``torch.jit.trace``.
         strict_shapes : bool
             Test that the traced function errors on inputs with feature dimensions that don't match the input irreps.
     Returns
@@ -375,14 +343,12 @@ def assert_auto_jitable(
     # Test tracing
     with warnings.catch_warnings():
         if error_on_warnings:
-            warnings.filterwarnings('error', category=torch.jit.TracerWarning)
-        func_jit = compile(
-            func,
-            n_trace_checks=n_trace_checks
-        )
+            warnings.filterwarnings("error", category=torch.jit.TracerWarning)
+        func_jit = compile(func, n_trace_checks=n_trace_checks)
 
     # Confirm that it rejects incorrect shapes
-    # This check only makes sense if all inputs are Tensors with irreps; otherwise we can't know how to modify the arguments or that our modifications make them wrong.
+    # This check only makes sense if all inputs are Tensors with irreps; otherwise we can't know how to modify the arguments
+    # or that our modifications make them wrong.
     if strict_shapes and not hasattr(func, _MAKE_TRACING_INPUTS):
         try:
             all_bad_args = get_tracing_inputs(func, n=1)[0]
@@ -394,13 +360,13 @@ def assert_auto_jitable(
                 # Since _rand_args is OK, they're all Irreps style args where changing the feature dimension is wrong
                 bad_which = random.randint(0, len(bad_args) - 1)
                 bad_args = list(bad_args)
-                bad_args[bad_which] = bad_args[bad_which][..., :-random.randint(1, 3)]  # make bad shape
+                bad_args[bad_which] = bad_args[bad_which][..., : -random.randint(1, 3)]  # make bad shape
                 try:
-                    if method == 'forward':
+                    if method == "forward":
                         func_jit(*bad_args)
                     else:
                         getattr(func_jit, method)(*bad_args)
-                except (torch.jit.Error, RuntimeError):
+                except (torch.jit.Error, RuntimeError):  # type: ignore
                     # As far as I can tell, there's no good way to introspect TorchScript exceptions.
                     pass
                 else:
@@ -424,7 +390,8 @@ def assert_normalized(
 
     See https://docs.e3nn.org/en/stable/guide/normalization.html for more information on the normalization scheme.
 
-    ``atol``, ``n_input``, and ``n_weight`` may need to be significantly higher in order to converge the statistics to pass the test.
+    ``atol``, ``n_input``, and ``n_weight`` may need to be significantly higher in order to converge the statistics
+    to pass the test.
 
     Parameters
     ----------
@@ -435,7 +402,8 @@ def assert_normalized(
         irreps_out : object
             see ``equivariance_error``
         normalization : str, default "component"
-            one of "component" or "norm". Note that this is defined for both the inputs and the outputs; if you need seperate normalizations for input and output please file a feature request.
+            one of "component" or "norm". Note that this is defined for both the inputs and the outputs; if you need seperate
+            normalizations for input and output please file a feature request.
         n_input : int, default 10_000
             the number of input samples to use for each weight init
         n_weight : int, default 20
@@ -516,12 +484,11 @@ def assert_normalized(
             if ir_slice.start == ir_slice.stop:
                 continue
             max_componentwise = (expected_square[ir_slice] - target).abs().max().item()
-            logger.info(
-                "Tested normalization of %r: max componentwise error %.6f",
-                _logging_name(func),
-                max_componentwise
+            logger.info("Tested normalization of %r: max componentwise error %.6f", _logging_name(func), max_componentwise)
+            assert max_componentwise <= atol, (
+                f"< x_i^2 > !~= {target:.6f} for output irrep #{i}, {irreps[i]}."
+                f"Max componentwise error: {max_componentwise:.6f}"
             )
-            assert max_componentwise <= atol, f"< x_i^2 > !~= {target:.6f} for output irrep #{i}, {irreps[i]}. Max componentwise error: {max_componentwise:.6f}"
 
 
 def set_random_seeds():
